OC.L10N.register(
    "comments",
    {
    "<strong>Comments</strong> for files" : "<strong>Kommentit</strong> tiedostoille",
    "%1$s commented" : "%1$s kommentoi",
    "%1$s commented on %2$s" : "%1$s kommentoi kohdetta %2$s",
    "Comments" : "Kommentit",
    "Type in a new comment..." : "Kirjoita uusi kommentti...",
    "Delete comment" : "Poista kommentti",
    "Post" : "Lähetä",
    "Cancel" : "Peruuta",
    "Edit comment" : "Muokkaa kommenttia",
    "[Deleted user]" : "[Poistettu käyttäjä]",
    "No other comments available" : "Ei muita kommentteja saatavilla",
    "More comments..." : "Lisää kommentteja...",
    "Save" : "Tallenna",
    "Allowed characters {count} of {max}" : "Sallittujen merkkien määrä {count}/{max}",
    "{count} unread comments" : "{count} lukematonta kommenttia",
    "Comment" : "Kommentti",
    "<strong>Comments</strong> for files" : "<strong>Kommentit</strong> tiedostoille"
},
"nplurals=2; plural=(n != 1);");
